#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17]*x[0] + p[7]*(x[1] - y[17]);
out[1] = (1.0/2.0)*(-p[15]*(x[1] - y[17]) - y[4]*(p[16]*y[4] + y[0]*sin(x[0] - y[1])) - y[5]*(p[16]*y[5] + y[0]*cos(x[0] - y[1])) + y[9])/p[8];
out[2] = (-x[2] - y[4]*(-p[13] + p[11]) + u[4])/p[9];
out[3] = (-x[3] + y[5]*(-p[14] + p[12]))/p[10];
out[4] = (y[8] - x[4])/p[20];
out[5] = (x[4] - x[5])/p[22];
out[6] = p[23]*(u[5] - y[6]) - 9.9999999999999995e-7*x[6];
out[7] = -p[36]*x[7] + p[26]*(x[8] - y[17]);
out[8] = (1.0/2.0)*(-p[34]*(x[8] - y[17]) - y[10]*(p[35]*y[10] + y[2]*sin(x[7] - y[3])) - y[11]*(p[35]*y[11] + y[2]*cos(x[7] - y[3])) + y[16])/p[27];
out[9] = (-x[9] - y[10]*(-p[32] + p[30]) + y[14])/p[28];
out[10] = (-x[10] + y[11]*(-p[33] + p[31]))/p[29];
out[11] = (y[2] - x[11])/p[40];
out[12] = -p[43]*(p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] - y[14]) - x[11] + u[8] + u[7];
out[13] = (y[15] - x[13])/p[45];
out[14] = (x[13] - x[14])/p[47];
out[15] = p[48]*(u[9] - y[12]) - 9.9999999999999995e-7*x[15];
out[16] = -p[52]*x[16] - y[17] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[6]*y[6]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[6]*y[7]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1] - p[25]*y[12]/p[0];
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - 1.0/2.0*p[3]) - p[25]*y[13]/p[0];
out[4] = p[16]*y[5] + y[0]*cos(x[0] - y[1]) + p[13]*y[4] - x[2];
out[5] = p[16]*y[4] + y[0]*sin(x[0] - y[1]) - p[14]*y[5] - x[3];
out[6] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]) - y[6];
out[7] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]) - y[7];
out[8] = p[18]*y[18] - y[8] + u[6] + x[6] - (x[1] - p[24])/p[19];
out[9] = p[21]*(x[4] - x[5])/p[22] - y[9] + x[5];
out[10] = p[35]*y[11] + y[2]*cos(x[7] - y[3]) + p[32]*y[10] - x[9];
out[11] = p[35]*y[10] + y[2]*sin(x[7] - y[3]) - p[33]*y[11] - x[10];
out[12] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]) - y[12];
out[13] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]) - y[13];
out[14] = -y[14] + ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   p[41]
)
: ((p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   p[42]
)
: (
   p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]
)));
out[15] = p[37]*y[18] - y[15] + u[10] + x[15] - (x[8] - p[49])/p[44];
out[16] = p[46]*(x[13] - x[14])/p[47] - y[16] + x[14];
out[17] = -y[17] + (p[8]*p[6]*x[1] + p[27]*p[25]*x[8])/(p[8]*p[6] + p[27]*p[25]);
out[18] = p[51]*x[16] + p[50]*(1 - y[17]) - y[18];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17]*x[0] + p[7]*(x[1] - y[17]);
out[1] = (1.0/2.0)*(-p[15]*(x[1] - y[17]) - y[4]*(p[16]*y[4] + y[0]*sin(x[0] - y[1])) - y[5]*(p[16]*y[5] + y[0]*cos(x[0] - y[1])) + y[9])/p[8];
out[2] = (-x[2] - y[4]*(-p[13] + p[11]) + u[4])/p[9];
out[3] = (-x[3] + y[5]*(-p[14] + p[12]))/p[10];
out[4] = (y[8] - x[4])/p[20];
out[5] = (x[4] - x[5])/p[22];
out[6] = p[23]*(u[5] - y[6]) - 9.9999999999999995e-7*x[6];
out[7] = -p[36]*x[7] + p[26]*(x[8] - y[17]);
out[8] = (1.0/2.0)*(-p[34]*(x[8] - y[17]) - y[10]*(p[35]*y[10] + y[2]*sin(x[7] - y[3])) - y[11]*(p[35]*y[11] + y[2]*cos(x[7] - y[3])) + y[16])/p[27];
out[9] = (-x[9] - y[10]*(-p[32] + p[30]) + y[14])/p[28];
out[10] = (-x[10] + y[11]*(-p[33] + p[31]))/p[29];
out[11] = (y[2] - x[11])/p[40];
out[12] = -p[43]*(p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] - y[14]) - x[11] + u[8] + u[7];
out[13] = (y[15] - x[13])/p[45];
out[14] = (x[13] - x[14])/p[47];
out[15] = p[48]*(u[9] - y[12]) - 9.9999999999999995e-7*x[15];
out[16] = -p[52]*x[16] - y[17] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[6]*y[6]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[6]*y[7]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1] - p[25]*y[12]/p[0];
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - 1.0/2.0*p[3]) - p[25]*y[13]/p[0];
out[4] = p[16]*y[5] + y[0]*cos(x[0] - y[1]) + p[13]*y[4] - x[2];
out[5] = p[16]*y[4] + y[0]*sin(x[0] - y[1]) - p[14]*y[5] - x[3];
out[6] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]) - y[6];
out[7] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]) - y[7];
out[8] = p[18]*y[18] - y[8] + u[6] + x[6] - (x[1] - p[24])/p[19];
out[9] = p[21]*(x[4] - x[5])/p[22] - y[9] + x[5];
out[10] = p[35]*y[11] + y[2]*cos(x[7] - y[3]) + p[32]*y[10] - x[9];
out[11] = p[35]*y[10] + y[2]*sin(x[7] - y[3]) - p[33]*y[11] - x[10];
out[12] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]) - y[12];
out[13] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]) - y[13];
out[14] = -y[14] + ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   p[41]
)
: ((p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   p[42]
)
: (
   p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]
)));
out[15] = p[37]*y[18] - y[15] + u[10] + x[15] - (x[8] - p[49])/p[44];
out[16] = p[46]*(x[13] - x[14])/p[47] - y[16] + x[14];
out[17] = -y[17] + (p[8]*p[6]*x[1] + p[27]*p[25]*x[8])/(p[8]*p[6] + p[27]*p[25]);
out[18] = p[51]*x[16] + p[50]*(1 - y[17]) - y[18];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = y[0];
out[1] = y[2];
out[2] = pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[3] = -pow(y[0], 2)*p[2] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[4] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1];
out[5] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) - pow(y[2], 2)*p[2];
out[6] = y[4]*(p[16]*y[4] + y[0]*sin(x[0] - y[1])) + y[5]*(p[16]*y[5] + y[0]*cos(x[0] - y[1]));
out[7] = y[10]*(p[35]*y[10] + y[2]*sin(x[7] - y[3])) + y[11]*(p[35]*y[11] + y[2]*cos(x[7] - y[3]));

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[36] = 0.5*(-y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[53] = 0.5*(-y[4]*sin(x[0] - y[1]) - y[5]*cos(x[0] - y[1]))/p[8];
out[54] = 0.5*(y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[57] = 0.5*(-2.0*p[16]*y[4] - y[0]*sin(x[0] - y[1]))/p[8];
out[58] = 0.5*(-2.0*p[16]*y[5] - y[0]*cos(x[0] - y[1]))/p[8];
out[295] = 0.5*(-y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[307] = 0.5*(-y[10]*sin(x[7] - y[3]) - y[11]*cos(x[7] - y[3]))/p[27];
out[308] = 0.5*(y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[315] = 0.5*(-2.0*p[35]*y[10] - y[2]*sin(x[7] - y[3]))/p[27];
out[316] = 0.5*(-2.0*p[35]*y[11] - y[2]*cos(x[7] - y[3]))/p[27];
out[629] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[630] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[631] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[632] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[665] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[666] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[667] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[668] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[701] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[702] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[703] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[704] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[737] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[738] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[739] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[740] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[756] = -y[0]*sin(x[0] - y[1]);
out[773] = cos(x[0] - y[1]);
out[774] = y[0]*sin(x[0] - y[1]);
out[792] = y[0]*cos(x[0] - y[1]);
out[809] = sin(x[0] - y[1]);
out[810] = -y[0]*cos(x[0] - y[1]);
out[828] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]);
out[845] = y[4]*sin(x[0] - y[1]) + y[5]*cos(x[0] - y[1]);
out[846] = -y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]);
out[849] = y[0]*sin(x[0] - y[1]);
out[850] = y[0]*cos(x[0] - y[1]);
out[864] = -y[0]*y[4]*sin(x[0] - y[1]) - y[0]*y[5]*cos(x[0] - y[1]);
out[881] = y[4]*cos(x[0] - y[1]) - y[5]*sin(x[0] - y[1]);
out[882] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]);
out[885] = y[0]*cos(x[0] - y[1]);
out[886] = -y[0]*sin(x[0] - y[1]);
out[979] = -y[2]*sin(x[7] - y[3]);
out[991] = cos(x[7] - y[3]);
out[992] = y[2]*sin(x[7] - y[3]);
out[1015] = y[2]*cos(x[7] - y[3]);
out[1027] = sin(x[7] - y[3]);
out[1028] = -y[2]*cos(x[7] - y[3]);
out[1051] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]);
out[1063] = y[10]*sin(x[7] - y[3]) + y[11]*cos(x[7] - y[3]);
out[1064] = -y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]);
out[1071] = y[2]*sin(x[7] - y[3]);
out[1072] = y[2]*cos(x[7] - y[3]);
out[1087] = -y[2]*y[10]*sin(x[7] - y[3]) - y[2]*y[11]*cos(x[7] - y[3]);
out[1099] = y[10]*cos(x[7] - y[3]) - y[11]*sin(x[7] - y[3]);
out[1100] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]);
out[1107] = y[2]*cos(x[7] - y[3]);
out[1108] = -y[2]*sin(x[7] - y[3]);
out[1127] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   -p[38]
));
out[1128] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   p[39]
));

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[1] = p[7];
out[34] = -p[7];
out[37] = -0.5*p[15]/p[8];
out[62] = 0.5/p[8];
out[70] = 0.5*p[15]/p[8];
out[74] = -1/p[9];
out[93] = (p[13] - p[11])/p[9];
out[111] = -1/p[10];
out[130] = (-p[14] + p[12])/p[10];
out[148] = -1/p[20];
out[169] = 1.0/p[20];
out[184] = 1.0/p[22];
out[185] = -1/p[22];
out[239] = -p[23];
out[259] = -p[36];
out[260] = p[26];
out[286] = -p[26];
out[296] = -0.5*p[34]/p[27];
out[321] = 0.5/p[27];
out[322] = 0.5*p[34]/p[27];
out[333] = -1/p[28];
out[351] = (p[32] - p[30])/p[28];
out[355] = 1.0/p[28];
out[370] = -1/p[29];
out[388] = (-p[33] + p[31])/p[29];
out[407] = -1/p[40];
out[415] = 1.0/p[40];
out[443] = p[38]*p[43] - 1.0;
out[444] = -p[39]*p[43];
out[463] = p[43];
out[481] = -1/p[45];
out[500] = 1.0/p[45];
out[517] = 1.0/p[47];
out[518] = -1/p[47];
out[569] = -p[48];
out[592] = -p[52];
out[635] = -p[6]/p[0];
out[672] = -p[6]/p[0];
out[713] = -p[25]/p[0];
out[750] = -p[25]/p[0];
out[777] = p[13];
out[778] = p[16];
out[813] = p[16];
out[814] = -p[14];
out[901] = -1/p[19];
out[935] = p[18];
out[940] = p[21]/p[22];
out[941] = -p[21]/p[22] + 1.0;
out[999] = p[32];
out[1000] = p[35];
out[1035] = p[35];
out[1036] = -p[33];
out[1160] = -1/p[44];
out[1187] = p[37];
out[1201] = p[46]/p[47];
out[1202] = -p[46]/p[47] + 1.0;
out[1225] = p[8]*p[6]/(p[8]*p[6] + p[27]*p[25]);
out[1232] = p[27]*p[25]/(p[8]*p[6] + p[27]*p[25]);
out[1276] = p[51];
out[1294] = -p[50];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[222] = -9.9999999999999995e-7;
out[555] = -9.9999999999999995e-7;
out[610] = -1.0;
out[758] = -1.0;
out[795] = -1.0;
out[851] = -1.0;
out[888] = -1.0;
out[906] = 1.0;
out[925] = -1.0;
out[962] = -1.0;
out[981] = -1.0;
out[1018] = -1.0;
out[1073] = -1.0;
out[1110] = -1.0;
out[1147] = -1.0;
out[1167] = 1.0;
out[1184] = -1.0;
out[1221] = -1.0;
out[1258] = -1.0;
out[1295] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = 0.5*(-y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[5] = 0.5*(-y[4]*sin(x[0] - y[1]) - y[5]*cos(x[0] - y[1]))/p[8];
out[6] = 0.5*(y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[7] = 0.5*(-2.0*p[16]*y[4] - y[0]*sin(x[0] - y[1]))/p[8];
out[8] = 0.5*(-2.0*p[16]*y[5] - y[0]*cos(x[0] - y[1]))/p[8];
out[24] = 0.5*(-y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[26] = 0.5*(-y[10]*sin(x[7] - y[3]) - y[11]*cos(x[7] - y[3]))/p[27];
out[27] = 0.5*(y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[28] = 0.5*(-2.0*p[35]*y[10] - y[2]*sin(x[7] - y[3]))/p[27];
out[29] = 0.5*(-2.0*p[35]*y[11] - y[2]*cos(x[7] - y[3]))/p[27];
out[50] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[51] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[52] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[53] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[55] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[56] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[57] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[58] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[60] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[61] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[62] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[63] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[65] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[66] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[67] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[68] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[70] = -y[0]*sin(x[0] - y[1]);
out[72] = cos(x[0] - y[1]);
out[73] = y[0]*sin(x[0] - y[1]);
out[76] = y[0]*cos(x[0] - y[1]);
out[78] = sin(x[0] - y[1]);
out[79] = -y[0]*cos(x[0] - y[1]);
out[82] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]);
out[83] = y[4]*sin(x[0] - y[1]) + y[5]*cos(x[0] - y[1]);
out[84] = -y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]);
out[85] = y[0]*sin(x[0] - y[1]);
out[86] = y[0]*cos(x[0] - y[1]);
out[88] = -y[0]*y[4]*sin(x[0] - y[1]) - y[0]*y[5]*cos(x[0] - y[1]);
out[89] = y[4]*cos(x[0] - y[1]) - y[5]*sin(x[0] - y[1]);
out[90] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]);
out[91] = y[0]*cos(x[0] - y[1]);
out[92] = -y[0]*sin(x[0] - y[1]);
out[101] = -y[2]*sin(x[7] - y[3]);
out[103] = cos(x[7] - y[3]);
out[104] = y[2]*sin(x[7] - y[3]);
out[107] = y[2]*cos(x[7] - y[3]);
out[109] = sin(x[7] - y[3]);
out[110] = -y[2]*cos(x[7] - y[3]);
out[113] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]);
out[114] = y[10]*sin(x[7] - y[3]) + y[11]*cos(x[7] - y[3]);
out[115] = -y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]);
out[116] = y[2]*sin(x[7] - y[3]);
out[117] = y[2]*cos(x[7] - y[3]);
out[119] = -y[2]*y[10]*sin(x[7] - y[3]) - y[2]*y[11]*cos(x[7] - y[3]);
out[120] = y[10]*cos(x[7] - y[3]) - y[11]*sin(x[7] - y[3]);
out[121] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]);
out[122] = y[2]*cos(x[7] - y[3]);
out[123] = -y[2]*sin(x[7] - y[3]);
out[125] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   -p[38]
));
out[126] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   p[39]
));

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[1] = p[7];
out[2] = -p[7];
out[4] = -0.5*p[15]/p[8];
out[9] = 0.5/p[8];
out[10] = 0.5*p[15]/p[8];
out[11] = -1/p[9];
out[12] = (p[13] - p[11])/p[9];
out[13] = -1/p[10];
out[14] = (-p[14] + p[12])/p[10];
out[15] = -1/p[20];
out[16] = 1.0/p[20];
out[17] = 1.0/p[22];
out[18] = -1/p[22];
out[20] = -p[23];
out[21] = -p[36];
out[22] = p[26];
out[23] = -p[26];
out[25] = -0.5*p[34]/p[27];
out[30] = 0.5/p[27];
out[31] = 0.5*p[34]/p[27];
out[32] = -1/p[28];
out[33] = (p[32] - p[30])/p[28];
out[34] = 1.0/p[28];
out[35] = -1/p[29];
out[36] = (-p[33] + p[31])/p[29];
out[37] = -1/p[40];
out[38] = 1.0/p[40];
out[39] = p[38]*p[43] - 1.0;
out[40] = -p[39]*p[43];
out[41] = p[43];
out[42] = -1/p[45];
out[43] = 1.0/p[45];
out[44] = 1.0/p[47];
out[45] = -1/p[47];
out[47] = -p[48];
out[48] = -p[52];
out[54] = -p[6]/p[0];
out[59] = -p[6]/p[0];
out[64] = -p[25]/p[0];
out[69] = -p[25]/p[0];
out[74] = p[13];
out[75] = p[16];
out[80] = p[16];
out[81] = -p[14];
out[94] = -1/p[19];
out[97] = p[18];
out[98] = p[21]/p[22];
out[99] = -p[21]/p[22] + 1.0;
out[105] = p[32];
out[106] = p[35];
out[111] = p[35];
out[112] = -p[33];
out[128] = -1/p[44];
out[131] = p[37];
out[132] = p[46]/p[47];
out[133] = -p[46]/p[47] + 1.0;
out[135] = p[8]*p[6]/(p[8]*p[6] + p[27]*p[25]);
out[136] = p[27]*p[25]/(p[8]*p[6] + p[27]*p[25]);
out[138] = p[51];
out[139] = -p[50];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[19] = -9.9999999999999995e-7;
out[46] = -9.9999999999999995e-7;
out[49] = -1.0;
out[71] = -1.0;
out[77] = -1.0;
out[87] = -1.0;
out[93] = -1.0;
out[95] = 1.0;
out[96] = -1.0;
out[100] = -1.0;
out[102] = -1.0;
out[108] = -1.0;
out[118] = -1.0;
out[124] = -1.0;
out[127] = -1.0;
out[129] = 1.0;
out[130] = -1.0;
out[134] = -1.0;
out[137] = -1.0;
out[140] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[36] = 0.5*(-y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[53] = 0.5*(-y[4]*sin(x[0] - y[1]) - y[5]*cos(x[0] - y[1]))/p[8];
out[54] = 0.5*(y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[57] = 0.5*(-2.0*p[16]*y[4] - y[0]*sin(x[0] - y[1]))/p[8];
out[58] = 0.5*(-2.0*p[16]*y[5] - y[0]*cos(x[0] - y[1]))/p[8];
out[295] = 0.5*(-y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[307] = 0.5*(-y[10]*sin(x[7] - y[3]) - y[11]*cos(x[7] - y[3]))/p[27];
out[308] = 0.5*(y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[315] = 0.5*(-2.0*p[35]*y[10] - y[2]*sin(x[7] - y[3]))/p[27];
out[316] = 0.5*(-2.0*p[35]*y[11] - y[2]*cos(x[7] - y[3]))/p[27];
out[629] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[630] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[631] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[632] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[665] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[666] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[667] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[668] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[701] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[702] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[703] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[704] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[737] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[738] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[739] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[740] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[756] = -y[0]*sin(x[0] - y[1]);
out[773] = cos(x[0] - y[1]);
out[774] = y[0]*sin(x[0] - y[1]);
out[792] = y[0]*cos(x[0] - y[1]);
out[809] = sin(x[0] - y[1]);
out[810] = -y[0]*cos(x[0] - y[1]);
out[828] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]);
out[845] = y[4]*sin(x[0] - y[1]) + y[5]*cos(x[0] - y[1]);
out[846] = -y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]);
out[849] = y[0]*sin(x[0] - y[1]);
out[850] = y[0]*cos(x[0] - y[1]);
out[864] = -y[0]*y[4]*sin(x[0] - y[1]) - y[0]*y[5]*cos(x[0] - y[1]);
out[881] = y[4]*cos(x[0] - y[1]) - y[5]*sin(x[0] - y[1]);
out[882] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]);
out[885] = y[0]*cos(x[0] - y[1]);
out[886] = -y[0]*sin(x[0] - y[1]);
out[979] = -y[2]*sin(x[7] - y[3]);
out[991] = cos(x[7] - y[3]);
out[992] = y[2]*sin(x[7] - y[3]);
out[1015] = y[2]*cos(x[7] - y[3]);
out[1027] = sin(x[7] - y[3]);
out[1028] = -y[2]*cos(x[7] - y[3]);
out[1051] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]);
out[1063] = y[10]*sin(x[7] - y[3]) + y[11]*cos(x[7] - y[3]);
out[1064] = -y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]);
out[1071] = y[2]*sin(x[7] - y[3]);
out[1072] = y[2]*cos(x[7] - y[3]);
out[1087] = -y[2]*y[10]*sin(x[7] - y[3]) - y[2]*y[11]*cos(x[7] - y[3]);
out[1099] = y[10]*cos(x[7] - y[3]) - y[11]*sin(x[7] - y[3]);
out[1100] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]);
out[1107] = y[2]*cos(x[7] - y[3]);
out[1108] = -y[2]*sin(x[7] - y[3]);
out[1127] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   -p[38]
));
out[1128] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   p[39]
));

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[1] = p[7];
out[34] = -p[7];
out[37] = -0.5*p[15]/p[8];
out[62] = 0.5/p[8];
out[70] = 0.5*p[15]/p[8];
out[74] = -1/p[9];
out[93] = (p[13] - p[11])/p[9];
out[111] = -1/p[10];
out[130] = (-p[14] + p[12])/p[10];
out[148] = -1/p[20];
out[169] = 1.0/p[20];
out[184] = 1.0/p[22];
out[185] = -1/p[22];
out[239] = -p[23];
out[259] = -p[36];
out[260] = p[26];
out[286] = -p[26];
out[296] = -0.5*p[34]/p[27];
out[321] = 0.5/p[27];
out[322] = 0.5*p[34]/p[27];
out[333] = -1/p[28];
out[351] = (p[32] - p[30])/p[28];
out[355] = 1.0/p[28];
out[370] = -1/p[29];
out[388] = (-p[33] + p[31])/p[29];
out[407] = -1/p[40];
out[415] = 1.0/p[40];
out[443] = p[38]*p[43] - 1.0;
out[444] = -p[39]*p[43];
out[463] = p[43];
out[481] = -1/p[45];
out[500] = 1.0/p[45];
out[517] = 1.0/p[47];
out[518] = -1/p[47];
out[569] = -p[48];
out[592] = -p[52];
out[635] = -p[6]/p[0];
out[672] = -p[6]/p[0];
out[713] = -p[25]/p[0];
out[750] = -p[25]/p[0];
out[777] = p[13];
out[778] = p[16];
out[813] = p[16];
out[814] = -p[14];
out[901] = -1/p[19];
out[935] = p[18];
out[940] = p[21]/p[22];
out[941] = -p[21]/p[22] + 1.0;
out[999] = p[32];
out[1000] = p[35];
out[1035] = p[35];
out[1036] = -p[33];
out[1160] = -1/p[44];
out[1187] = p[37];
out[1201] = p[46]/p[47];
out[1202] = -p[46]/p[47] + 1.0;
out[1225] = p[8]*p[6]/(p[8]*p[6] + p[27]*p[25]);
out[1232] = p[27]*p[25]/(p[8]*p[6] + p[27]*p[25]);
out[1276] = p[51];
out[1294] = -p[50];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[222] = -9.9999999999999995e-7;
out[555] = -9.9999999999999995e-7;
out[610] = -1.0;
out[758] = -1.0;
out[795] = -1.0;
out[851] = -1.0;
out[888] = -1.0;
out[906] = 1.0;
out[925] = -1.0;
out[962] = -1.0;
out[981] = -1.0;
out[1018] = -1.0;
out[1073] = -1.0;
out[1110] = -1.0;
out[1147] = -1.0;
out[1167] = 1.0;
out[1184] = -1.0;
out[1221] = -1.0;
out[1258] = -1.0;
out[1295] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = 0.5*(-y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[5] = 0.5*(-y[4]*sin(x[0] - y[1]) - y[5]*cos(x[0] - y[1]))/p[8];
out[6] = 0.5*(y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[7] = 0.5*(-2.0*p[16]*y[4] - y[0]*sin(x[0] - y[1]))/p[8];
out[8] = 0.5*(-2.0*p[16]*y[5] - y[0]*cos(x[0] - y[1]))/p[8];
out[24] = 0.5*(-y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[26] = 0.5*(-y[10]*sin(x[7] - y[3]) - y[11]*cos(x[7] - y[3]))/p[27];
out[27] = 0.5*(y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[28] = 0.5*(-2.0*p[35]*y[10] - y[2]*sin(x[7] - y[3]))/p[27];
out[29] = 0.5*(-2.0*p[35]*y[11] - y[2]*cos(x[7] - y[3]))/p[27];
out[50] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[51] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[52] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[53] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[55] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[56] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[57] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[58] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[60] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[61] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[62] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[63] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[65] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[66] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[67] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[68] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[70] = -y[0]*sin(x[0] - y[1]);
out[72] = cos(x[0] - y[1]);
out[73] = y[0]*sin(x[0] - y[1]);
out[76] = y[0]*cos(x[0] - y[1]);
out[78] = sin(x[0] - y[1]);
out[79] = -y[0]*cos(x[0] - y[1]);
out[82] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]);
out[83] = y[4]*sin(x[0] - y[1]) + y[5]*cos(x[0] - y[1]);
out[84] = -y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]);
out[85] = y[0]*sin(x[0] - y[1]);
out[86] = y[0]*cos(x[0] - y[1]);
out[88] = -y[0]*y[4]*sin(x[0] - y[1]) - y[0]*y[5]*cos(x[0] - y[1]);
out[89] = y[4]*cos(x[0] - y[1]) - y[5]*sin(x[0] - y[1]);
out[90] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]);
out[91] = y[0]*cos(x[0] - y[1]);
out[92] = -y[0]*sin(x[0] - y[1]);
out[101] = -y[2]*sin(x[7] - y[3]);
out[103] = cos(x[7] - y[3]);
out[104] = y[2]*sin(x[7] - y[3]);
out[107] = y[2]*cos(x[7] - y[3]);
out[109] = sin(x[7] - y[3]);
out[110] = -y[2]*cos(x[7] - y[3]);
out[113] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]);
out[114] = y[10]*sin(x[7] - y[3]) + y[11]*cos(x[7] - y[3]);
out[115] = -y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]);
out[116] = y[2]*sin(x[7] - y[3]);
out[117] = y[2]*cos(x[7] - y[3]);
out[119] = -y[2]*y[10]*sin(x[7] - y[3]) - y[2]*y[11]*cos(x[7] - y[3]);
out[120] = y[10]*cos(x[7] - y[3]) - y[11]*sin(x[7] - y[3]);
out[121] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]);
out[122] = y[2]*cos(x[7] - y[3]);
out[123] = -y[2]*sin(x[7] - y[3]);
out[125] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   -p[38]
));
out[126] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   p[39]
));

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[1] = p[7];
out[2] = -p[7];
out[4] = -0.5*p[15]/p[8];
out[9] = 0.5/p[8];
out[10] = 0.5*p[15]/p[8];
out[11] = -1/p[9];
out[12] = (p[13] - p[11])/p[9];
out[13] = -1/p[10];
out[14] = (-p[14] + p[12])/p[10];
out[15] = -1/p[20];
out[16] = 1.0/p[20];
out[17] = 1.0/p[22];
out[18] = -1/p[22];
out[20] = -p[23];
out[21] = -p[36];
out[22] = p[26];
out[23] = -p[26];
out[25] = -0.5*p[34]/p[27];
out[30] = 0.5/p[27];
out[31] = 0.5*p[34]/p[27];
out[32] = -1/p[28];
out[33] = (p[32] - p[30])/p[28];
out[34] = 1.0/p[28];
out[35] = -1/p[29];
out[36] = (-p[33] + p[31])/p[29];
out[37] = -1/p[40];
out[38] = 1.0/p[40];
out[39] = p[38]*p[43] - 1.0;
out[40] = -p[39]*p[43];
out[41] = p[43];
out[42] = -1/p[45];
out[43] = 1.0/p[45];
out[44] = 1.0/p[47];
out[45] = -1/p[47];
out[47] = -p[48];
out[48] = -p[52];
out[54] = -p[6]/p[0];
out[59] = -p[6]/p[0];
out[64] = -p[25]/p[0];
out[69] = -p[25]/p[0];
out[74] = p[13];
out[75] = p[16];
out[80] = p[16];
out[81] = -p[14];
out[94] = -1/p[19];
out[97] = p[18];
out[98] = p[21]/p[22];
out[99] = -p[21]/p[22] + 1.0;
out[105] = p[32];
out[106] = p[35];
out[111] = p[35];
out[112] = -p[33];
out[128] = -1/p[44];
out[131] = p[37];
out[132] = p[46]/p[47];
out[133] = -p[46]/p[47] + 1.0;
out[135] = p[8]*p[6]/(p[8]*p[6] + p[27]*p[25]);
out[136] = p[27]*p[25]/(p[8]*p[6] + p[27]*p[25]);
out[138] = p[51];
out[139] = -p[50];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[19] = -9.9999999999999995e-7;
out[46] = -9.9999999999999995e-7;
out[49] = -1.0;
out[71] = -1.0;
out[77] = -1.0;
out[87] = -1.0;
out[93] = -1.0;
out[95] = 1.0;
out[96] = -1.0;
out[100] = -1.0;
out[102] = -1.0;
out[108] = -1.0;
out[118] = -1.0;
out[124] = -1.0;
out[127] = -1.0;
out[129] = 1.0;
out[130] = -1.0;
out[134] = -1.0;
out[137] = -1.0;
out[140] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[36] = -0.25*Dt*(-y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[53] = -0.25*Dt*(-y[4]*sin(x[0] - y[1]) - y[5]*cos(x[0] - y[1]))/p[8];
out[54] = -0.25*Dt*(y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[57] = -0.25*Dt*(-2.0*p[16]*y[4] - y[0]*sin(x[0] - y[1]))/p[8];
out[58] = -0.25*Dt*(-2.0*p[16]*y[5] - y[0]*cos(x[0] - y[1]))/p[8];
out[295] = -0.25*Dt*(-y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[307] = -0.25*Dt*(-y[10]*sin(x[7] - y[3]) - y[11]*cos(x[7] - y[3]))/p[27];
out[308] = -0.25*Dt*(y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[315] = -0.25*Dt*(-2.0*p[35]*y[10] - y[2]*sin(x[7] - y[3]))/p[27];
out[316] = -0.25*Dt*(-2.0*p[35]*y[11] - y[2]*cos(x[7] - y[3]))/p[27];
out[629] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[630] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[631] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[632] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[665] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[666] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[667] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[668] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[701] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[702] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[703] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[704] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[737] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[738] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[739] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[740] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[756] = -y[0]*sin(x[0] - y[1]);
out[773] = cos(x[0] - y[1]);
out[774] = y[0]*sin(x[0] - y[1]);
out[792] = y[0]*cos(x[0] - y[1]);
out[809] = sin(x[0] - y[1]);
out[810] = -y[0]*cos(x[0] - y[1]);
out[828] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]);
out[845] = y[4]*sin(x[0] - y[1]) + y[5]*cos(x[0] - y[1]);
out[846] = -y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]);
out[849] = y[0]*sin(x[0] - y[1]);
out[850] = y[0]*cos(x[0] - y[1]);
out[864] = -y[0]*y[4]*sin(x[0] - y[1]) - y[0]*y[5]*cos(x[0] - y[1]);
out[881] = y[4]*cos(x[0] - y[1]) - y[5]*sin(x[0] - y[1]);
out[882] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]);
out[885] = y[0]*cos(x[0] - y[1]);
out[886] = -y[0]*sin(x[0] - y[1]);
out[979] = -y[2]*sin(x[7] - y[3]);
out[991] = cos(x[7] - y[3]);
out[992] = y[2]*sin(x[7] - y[3]);
out[1015] = y[2]*cos(x[7] - y[3]);
out[1027] = sin(x[7] - y[3]);
out[1028] = -y[2]*cos(x[7] - y[3]);
out[1051] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]);
out[1063] = y[10]*sin(x[7] - y[3]) + y[11]*cos(x[7] - y[3]);
out[1064] = -y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]);
out[1071] = y[2]*sin(x[7] - y[3]);
out[1072] = y[2]*cos(x[7] - y[3]);
out[1087] = -y[2]*y[10]*sin(x[7] - y[3]) - y[2]*y[11]*cos(x[7] - y[3]);
out[1099] = y[10]*cos(x[7] - y[3]) - y[11]*sin(x[7] - y[3]);
out[1100] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]);
out[1107] = y[2]*cos(x[7] - y[3]);
out[1108] = -y[2]*sin(x[7] - y[3]);
out[1127] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   -p[38]
));
out[1128] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   p[39]
));

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[17] + 1.0;
out[1] = -0.5*Dt*p[7];
out[34] = 0.5*Dt*p[7];
out[37] = 0.25*p[15]*Dt/p[8] + 1.0;
out[62] = -0.25*Dt/p[8];
out[70] = -0.25*p[15]*Dt/p[8];
out[74] = 0.5*Dt/p[9] + 1.0;
out[93] = -0.5*Dt*(p[13] - p[11])/p[9];
out[111] = 0.5*Dt/p[10] + 1.0;
out[130] = -0.5*Dt*(-p[14] + p[12])/p[10];
out[148] = 0.5*Dt/p[20] + 1.0;
out[169] = -0.5*Dt/p[20];
out[184] = -0.5*Dt/p[22];
out[185] = 0.5*Dt/p[22] + 1.0;
out[222] = 4.9999999999999998e-7*Dt + 1.0;
out[239] = 0.5*Dt*p[23];
out[259] = 0.5*Dt*p[36] + 1.0;
out[260] = -0.5*Dt*p[26];
out[286] = 0.5*Dt*p[26];
out[296] = 0.25*p[34]*Dt/p[27] + 1.0;
out[321] = -0.25*Dt/p[27];
out[322] = -0.25*p[34]*Dt/p[27];
out[333] = 0.5*Dt/p[28] + 1.0;
out[351] = -0.5*Dt*(p[32] - p[30])/p[28];
out[355] = -0.5*Dt/p[28];
out[370] = 0.5*Dt/p[29] + 1.0;
out[388] = -0.5*Dt*(-p[33] + p[31])/p[29];
out[407] = 0.5*Dt/p[40] + 1.0;
out[415] = -0.5*Dt/p[40];
out[443] = -0.5*Dt*(p[38]*p[43] - 1.0);
out[444] = 0.5*Dt*p[39]*p[43] + 1.0;
out[463] = -0.5*Dt*p[43];
out[481] = 0.5*Dt/p[45] + 1.0;
out[500] = -0.5*Dt/p[45];
out[517] = -0.5*Dt/p[47];
out[518] = 0.5*Dt/p[47] + 1.0;
out[555] = 4.9999999999999998e-7*Dt + 1.0;
out[569] = 0.5*Dt*p[48];
out[592] = 0.5*Dt*p[52] + 1.0;
out[610] = 0.5*Dt;
out[635] = -p[6]/p[0];
out[672] = -p[6]/p[0];
out[713] = -p[25]/p[0];
out[750] = -p[25]/p[0];
out[777] = p[13];
out[778] = p[16];
out[813] = p[16];
out[814] = -p[14];
out[901] = -1/p[19];
out[935] = p[18];
out[940] = p[21]/p[22];
out[941] = -p[21]/p[22] + 1.0;
out[999] = p[32];
out[1000] = p[35];
out[1035] = p[35];
out[1036] = -p[33];
out[1160] = -1/p[44];
out[1187] = p[37];
out[1201] = p[46]/p[47];
out[1202] = -p[46]/p[47] + 1.0;
out[1225] = p[8]*p[6]/(p[8]*p[6] + p[27]*p[25]);
out[1232] = p[27]*p[25]/(p[8]*p[6] + p[27]*p[25]);
out[1276] = p[51];
out[1294] = -p[50];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[758] = -1.0;
out[795] = -1.0;
out[851] = -1.0;
out[888] = -1.0;
out[906] = 1.0;
out[925] = -1.0;
out[962] = -1.0;
out[981] = -1.0;
out[1018] = -1.0;
out[1073] = -1.0;
out[1110] = -1.0;
out[1147] = -1.0;
out[1167] = 1.0;
out[1184] = -1.0;
out[1221] = -1.0;
out[1258] = -1.0;
out[1295] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -0.25*Dt*(-y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[5] = -0.25*Dt*(-y[4]*sin(x[0] - y[1]) - y[5]*cos(x[0] - y[1]))/p[8];
out[6] = -0.25*Dt*(y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]))/p[8];
out[7] = -0.25*Dt*(-2.0*p[16]*y[4] - y[0]*sin(x[0] - y[1]))/p[8];
out[8] = -0.25*Dt*(-2.0*p[16]*y[5] - y[0]*cos(x[0] - y[1]))/p[8];
out[24] = -0.25*Dt*(-y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[26] = -0.25*Dt*(-y[10]*sin(x[7] - y[3]) - y[11]*cos(x[7] - y[3]))/p[27];
out[27] = -0.25*Dt*(y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]))/p[27];
out[28] = -0.25*Dt*(-2.0*p[35]*y[10] - y[2]*sin(x[7] - y[3]))/p[27];
out[29] = -0.25*Dt*(-2.0*p[35]*y[11] - y[2]*cos(x[7] - y[3]))/p[27];
out[50] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[51] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[52] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[53] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[55] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[56] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[57] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[58] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[60] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[61] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[62] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[63] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[65] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[66] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[67] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[68] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[70] = -y[0]*sin(x[0] - y[1]);
out[72] = cos(x[0] - y[1]);
out[73] = y[0]*sin(x[0] - y[1]);
out[76] = y[0]*cos(x[0] - y[1]);
out[78] = sin(x[0] - y[1]);
out[79] = -y[0]*cos(x[0] - y[1]);
out[82] = y[0]*y[4]*cos(x[0] - y[1]) - y[0]*y[5]*sin(x[0] - y[1]);
out[83] = y[4]*sin(x[0] - y[1]) + y[5]*cos(x[0] - y[1]);
out[84] = -y[0]*y[4]*cos(x[0] - y[1]) + y[0]*y[5]*sin(x[0] - y[1]);
out[85] = y[0]*sin(x[0] - y[1]);
out[86] = y[0]*cos(x[0] - y[1]);
out[88] = -y[0]*y[4]*sin(x[0] - y[1]) - y[0]*y[5]*cos(x[0] - y[1]);
out[89] = y[4]*cos(x[0] - y[1]) - y[5]*sin(x[0] - y[1]);
out[90] = y[0]*y[4]*sin(x[0] - y[1]) + y[0]*y[5]*cos(x[0] - y[1]);
out[91] = y[0]*cos(x[0] - y[1]);
out[92] = -y[0]*sin(x[0] - y[1]);
out[101] = -y[2]*sin(x[7] - y[3]);
out[103] = cos(x[7] - y[3]);
out[104] = y[2]*sin(x[7] - y[3]);
out[107] = y[2]*cos(x[7] - y[3]);
out[109] = sin(x[7] - y[3]);
out[110] = -y[2]*cos(x[7] - y[3]);
out[113] = y[2]*y[10]*cos(x[7] - y[3]) - y[2]*y[11]*sin(x[7] - y[3]);
out[114] = y[10]*sin(x[7] - y[3]) + y[11]*cos(x[7] - y[3]);
out[115] = -y[2]*y[10]*cos(x[7] - y[3]) + y[2]*y[11]*sin(x[7] - y[3]);
out[116] = y[2]*sin(x[7] - y[3]);
out[117] = y[2]*cos(x[7] - y[3]);
out[119] = -y[2]*y[10]*sin(x[7] - y[3]) - y[2]*y[11]*cos(x[7] - y[3]);
out[120] = y[10]*cos(x[7] - y[3]) - y[11]*sin(x[7] - y[3]);
out[121] = y[2]*y[10]*sin(x[7] - y[3]) + y[2]*y[11]*cos(x[7] - y[3]);
out[122] = y[2]*cos(x[7] - y[3]);
out[123] = -y[2]*sin(x[7] - y[3]);
out[125] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   -p[38]
));
out[126] = ((p[41] > p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12] || p[42] < p[38]*(-x[11] + u[8] + u[7]) + p[39]*x[12]) ? (
   0
)
: (
   p[39]
));

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[17] + 1.0;
out[1] = -0.5*Dt*p[7];
out[2] = 0.5*Dt*p[7];
out[4] = 0.25*p[15]*Dt/p[8] + 1.0;
out[9] = -0.25*Dt/p[8];
out[10] = -0.25*p[15]*Dt/p[8];
out[11] = 0.5*Dt/p[9] + 1.0;
out[12] = -0.5*Dt*(p[13] - p[11])/p[9];
out[13] = 0.5*Dt/p[10] + 1.0;
out[14] = -0.5*Dt*(-p[14] + p[12])/p[10];
out[15] = 0.5*Dt/p[20] + 1.0;
out[16] = -0.5*Dt/p[20];
out[17] = -0.5*Dt/p[22];
out[18] = 0.5*Dt/p[22] + 1.0;
out[19] = 4.9999999999999998e-7*Dt + 1.0;
out[20] = 0.5*Dt*p[23];
out[21] = 0.5*Dt*p[36] + 1.0;
out[22] = -0.5*Dt*p[26];
out[23] = 0.5*Dt*p[26];
out[25] = 0.25*p[34]*Dt/p[27] + 1.0;
out[30] = -0.25*Dt/p[27];
out[31] = -0.25*p[34]*Dt/p[27];
out[32] = 0.5*Dt/p[28] + 1.0;
out[33] = -0.5*Dt*(p[32] - p[30])/p[28];
out[34] = -0.5*Dt/p[28];
out[35] = 0.5*Dt/p[29] + 1.0;
out[36] = -0.5*Dt*(-p[33] + p[31])/p[29];
out[37] = 0.5*Dt/p[40] + 1.0;
out[38] = -0.5*Dt/p[40];
out[39] = -0.5*Dt*(p[38]*p[43] - 1.0);
out[40] = 0.5*Dt*p[39]*p[43] + 1.0;
out[41] = -0.5*Dt*p[43];
out[42] = 0.5*Dt/p[45] + 1.0;
out[43] = -0.5*Dt/p[45];
out[44] = -0.5*Dt/p[47];
out[45] = 0.5*Dt/p[47] + 1.0;
out[46] = 4.9999999999999998e-7*Dt + 1.0;
out[47] = 0.5*Dt*p[48];
out[48] = 0.5*Dt*p[52] + 1.0;
out[49] = 0.5*Dt;
out[54] = -p[6]/p[0];
out[59] = -p[6]/p[0];
out[64] = -p[25]/p[0];
out[69] = -p[25]/p[0];
out[74] = p[13];
out[75] = p[16];
out[80] = p[16];
out[81] = -p[14];
out[94] = -1/p[19];
out[97] = p[18];
out[98] = p[21]/p[22];
out[99] = -p[21]/p[22] + 1.0;
out[105] = p[32];
out[106] = p[35];
out[111] = p[35];
out[112] = -p[33];
out[128] = -1/p[44];
out[131] = p[37];
out[132] = p[46]/p[47];
out[133] = -p[46]/p[47] + 1.0;
out[135] = p[8]*p[6]/(p[8]*p[6] + p[27]*p[25]);
out[136] = p[27]*p[25]/(p[8]*p[6] + p[27]*p[25]);
out[138] = p[51];
out[139] = -p[50];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[71] = -1.0;
out[77] = -1.0;
out[87] = -1.0;
out[93] = -1.0;
out[95] = 1.0;
out[96] = -1.0;
out[100] = -1.0;
out[102] = -1.0;
out[108] = -1.0;
out[118] = -1.0;
out[124] = -1.0;
out[127] = -1.0;
out[129] = 1.0;
out[130] = -1.0;
out[134] = -1.0;
out[137] = -1.0;
out[140] = -1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  23,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_smib_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_smib_cffi(void) { return NULL; }
#  else
     initsmib_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_smib_cffi(void)
{
  return _cffi_init("smib_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
initsmib_cffi(void)
{
  _cffi_init("smib_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
